==> owncloud-9.1.3.zip: owncloud/apps/federatedfilesharing/l10n/ca.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartició federada",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "File is already shared with %s" : "El fitxer ja està compartit amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has rebut \"/%3$s\" com una compartició remota des de %1$s (de part de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Has rebut \"/%3$s\" com una compartició remota de %1$s",
    "Accept" : "Acceptar",
    "Decline" : "Denegar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparteix amb mi a través del meu #ownCloud ID de Núvol Federat, consulteu %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparteix amb mi a través del meu #ownCloud ID de Núvol Federat",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "Open documentation" : "Obre la documentació",
    "Allow users on this server to send shares to other servers" : "Permet als usuaris d'aquest servidor enviar comparticions a d'altres servidors",
    "Allow users on this server to receive shares from other servers" : "Permet als usuaris d'aquest servidor rebre comparticions a d'altres servidors",
    "Federated Cloud" : "Núvol federat",
    "Your Federated Cloud ID:" : "El teu ID de Núvol Federat:",
    "Share it:" : "Comparteix-lo:",
    "Add to your website" : "Afegeix a la teva pàgina web",
    "Share with me via ownCloud" : "Comparteix amb mi amb ownCloud",
    "HTML Code:" : "Codi HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/ca.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartició federada",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "File is already shared with %s" : "El fitxer ja està compartit amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has rebut \"/%3$s\" com una compartició remota des de %1$s (de part de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Has rebut \"/%3$s\" com una compartició remota de %1$s",
    "Accept" : "Acceptar",
    "Decline" : "Denegar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparteix amb mi a través del meu #ownCloud ID de Núvol Federat, consulteu %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparteix amb mi a través del meu #ownCloud ID de Núvol Federat",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "Open documentation" : "Obre la documentació",
    "Allow users on this server to send shares to other servers" : "Permet als usuaris d'aquest servidor enviar comparticions a d'altres servidors",
    "Allow users on this server to receive shares from other servers" : "Permet als usuaris d'aquest servidor rebre comparticions a d'altres servidors",
    "Federated Cloud" : "Núvol federat",
    "Your Federated Cloud ID:" : "El teu ID de Núvol Federat:",
    "Share it:" : "Comparteix-lo:",
    "Add to your website" : "Afegeix a la teva pàgina web",
    "Share with me via ownCloud" : "Comparteix amb mi amb ownCloud",
    "HTML Code:" : "Codi HTML:",
    "Add to your ownCloud" : "Afegiu a ownCloud"
},
"nplurals=2; plural=(n != 1);");
